@@ -1,16 +1,13 @@
 package Video::Delay::Func;
 
-# Pragmas.
 use strict;
 use warnings;
 
-# Modules.
 use Class::Utils qw(set_params);
 use English qw(-no_match_vars);
 use Error::Pure qw(err);
 
-# Version.
-our $VERSION = 0.06;
+our $VERSION = 0.07;
 
 # Constructor.
 sub new {
@@ -87,6 +84,7 @@ Video::Delay::Func - Video::Delay class for delays defined by math function.
 =head1 SYNOPSIS
 
  use Video::Delay::Func;
+
  my $obj = Video::Delay::Func->new(%parameters);
  my $delay = $obj->delay;
 
@@ -137,11 +135,9 @@ Video::Delay::Func - Video::Delay class for delays defined by math function.
 
 =head1 EXAMPLE1
 
- # Pragmas.
  use strict;
  use warnings;
 
- # Modules.
  use Video::Delay::Func;
 
  # Object.
@@ -165,11 +161,9 @@ Video::Delay::Func - Video::Delay class for delays defined by math function.
 
 =head1 EXAMPLE2
 
- # Pragmas.
  use strict;
  use warnings;
 
- # Modules.
  use Video::Delay::Func;
 
  # Object.
@@ -206,21 +200,21 @@ Perl classes for delays between frames generation.
 
 =head1 REPOSITORY
 
-L<https://github.com/tupinek/Video-Delay>
+L<https://github.com/michal-josef-spacek/Video-Delay>
 
 =head1 AUTHOR
 
-Michal Špaček L<mailto:skim@cpan.org>
+Michal Josef Špaček L<mailto:skim@cpan.org>
 
 L<http://skim.cz>
 
 =head1 LICENSE AND COPYRIGHT
 
- © 2012-2015 Michal Špaček
+ © 2012-2020 Michal Josef Špaček
  BSD 2-Clause License
 
 =head1 VERSION
 
-0.06
+0.07
 
 =cut
